@@ -43,6 +43,22 @@ Alternatively, it can detect SVs from existing reads alignments in SAM/BAM forma
     parser_fasta.add_argument('genome',
                                type=str,
                                help='Reference genome file (FASTA)')
+    parser_fasta.add_argument('--verbose',
+                              action='store_true',
+                              help='Enable more verbose logging (default: %(default)s)')
+    group_fasta_align = parser_fasta.add_argument_group('ALIGN')
+    group_fasta_align.add_argument('--cores',
+                                        type=int,
+                                        default=1,
+                                        help='CPU cores to use for the alignment (default: %(default)s)')
+    group_fasta_align.add_argument('--aligner',
+                                        type=str,
+                                        default="ngmlr",
+                                        choices=["ngmlr", "minimap2"],
+                                        help='Tool for read alignment: ngmlr or minimap2 (default: %(default)s)')
+    group_fasta_align.add_argument('--nanopore',
+                                        action='store_true',
+                                        help='Use Nanopore settings for read alignment (default: %(default)s)')
     group_fasta_collect = parser_fasta.add_argument_group('COLLECT')
     group_fasta_collect.add_argument('--min_mapq',
                                         type=int,
@@ -68,18 +84,6 @@ Alternatively, it can detect SVs from existing reads alignments in SAM/BAM forma
                                               indicate a very long deletion (inversion) or a translocation breakpoint. \
                                               SVIM calls a translocation breakpoint if the mapping distance is larger \
                                               than this parameter and a deletion (or inversion) if it is smaller or equal.')
-    group_fasta_collect.add_argument('--cores',
-                                        type=int,
-                                        default=1,
-                                        help='CPU cores to use for the alignment (default: %(default)s)')
-    group_fasta_collect.add_argument('--aligner',
-                                        type=str,
-                                        default="ngmlr",
-                                        choices=["ngmlr", "minimap2"],
-                                        help='Tool for read alignment: ngmlr or minimap2 (default: %(default)s)')
-    group_fasta_collect.add_argument('--nanopore',
-                                        action='store_true',
-                                        help='Use Nanopore settings for read alignment (default: %(default)s)')
     group_fasta_collect.add_argument('--segment_gap_tolerance',
                                         type=int,
                                         default=10,
@@ -98,10 +102,19 @@ Alternatively, it can detect SVs from existing reads alignments in SAM/BAM forma
                                               far apart from each other on the reference. The segment overlap tolerance determines \
                                               the maximum tolerated length of an overlap between both segments on the read. If the \
                                               overlap between the two segments on the read is larger than this value, no deletion is called.')
+    group_fasta_collect.add_argument('--all_bnds',
+                                        action='store_true',
+                                        help='Output all rearrangements additionally in BND notation (default: %(default)s). \
+                                              By default, SV signatures from the read alignments are used to detect complete SVs, \
+                                              such as deletions, insertions and inversions. When this option is enabled, all SVs \
+                                              are also output in breakend (BND) notation as defined in the VCF specs. For instance, \
+                                              a deletion gets two records in the VCF output: 1. the normal <DEL> record and 2. \
+                                              a <BND> record representing the novel adjacency between the deletion\'s start and \
+                                              end coordinate in the sample genome.')
     group_fasta_cluster = parser_fasta.add_argument_group('CLUSTER')
     group_fasta_cluster.add_argument('--partition_max_distance',
                                         type=int,
-                                        default=5000,
+                                        default=1000,
                                         help='Maximum distance in bp between SVs in a partition (default: %(default)s). \
                                               Before clustering, the SV signatures are divided into coarse partitions. This parameter \
                                               determines the maximum distance between two subsequent signatures in the same partition. \
@@ -239,6 +252,9 @@ Alternatively, it can detect SVs from existing reads alignments in SAM/BAM forma
     parser_bam.add_argument('genome',
                                type=str,
                                help='Reference genome file that the long reads were aligned to (FASTA)')
+    parser_bam.add_argument('--verbose',
+                              action='store_true',
+                              help='Enable more verbose logging (default: %(default)s)')
     group_bam_collect = parser_bam.add_argument_group('COLLECT')
     group_bam_collect.add_argument('--min_mapq',
                                       type=int,
@@ -285,7 +301,7 @@ Alternatively, it can detect SVs from existing reads alignments in SAM/BAM forma
     group_bam_cluster = parser_bam.add_argument_group('CLUSTER')
     group_bam_cluster.add_argument('--partition_max_distance',
                                       type=int,
-                                      default=5000,
+                                      default=1000,
                                       help='Maximum distance in bp between SVs in a partition (default: %(default)s). \
                                             Before clustering, the SV signatures are divided into coarse partitions. This parameter \
                                             determines the maximum distance between two subsequent signatures in the same partition. \
@@ -316,6 +332,15 @@ Alternatively, it can detect SVs from existing reads alignments in SAM/BAM forma
                                             clusters with smaller distances between its members. \
                                             This parameter determines the height of the cut-off in the hierarchical clustering \
                                             dendrogram.')
+    group_bam_cluster.add_argument('--all_bnds',
+                                        action='store_true',
+                                        help='Output all rearrangements additionally in BND notation (default: %(default)s). \
+                                              By default, SV signatures from the read alignments are used to detect complete SVs, \
+                                              such as deletions, insertions and inversions. When this option is enabled, all SVs \
+                                              are also output in breakend (BND) notation as defined in the VCF specs. For instance, \
+                                              a deletion gets two records in the VCF output: 1. the normal <DEL> record and 2. \
+                                              a <BND> record representing the novel adjacency between the deletion\'s start and \
+                                              end coordinate in the sample genome.')
     group_bam_combine = parser_bam.add_argument_group('COMBINE')
     group_bam_combine.add_argument('--del_ins_dup_max_distance',
                                       type=float,
